==> trend_etl-1.4.7.tar.gz: trend_etl-1.4.7/trend_etl/tasks/uuid_assignment.py <==
import argparse
from typing import cast

from delta.tables import DeltaTable
from pyspark.sql import SparkSession

from trend_etl.functions.index import full_table_name
from trend_etl.transform.idents import from_bronze_get_idents_df
from trend_etl.functions.index import uuid_upsert_to_delta
import trend_etl.schema.args as arguments

program = "uuid_assignment"


def main() -> None:
    parser = argparse.ArgumentParser(description=f"Arguments for Trend ETL/{program}.")

    parser.add_argument(
        "--bronze-catalog",
        dest="bronze_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unity catalog to use",
    )

    parser.add_argument(
        "--target-catalog",
        dest="target_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unity catalog to use",
    )

    parser.add_argument(
        "--bronze-table",
        dest="bronze_table",
        required=True,
        choices=arguments.tables,
        help="The table in the selected schema",
    )

    parser.add_argument(
        "--target-table",
        dest="target_table",
        required=True,
        choices=arguments.tables,
        help="The table in the selected schema",
    )

    parser.add_argument(
        "--checkpoints-path-prefix",
        dest="checkpoints_path_prefix",
        required=True,
        help="The path to the folder (in S3) to store the checkpoints for this table",
    )

    parser.add_argument(
        "--id-json-path",
        dest="id_json_path",
        required=True,
        help="The the json path to the id field for the source document",
    )

    args = parser.parse_args()

    spark = cast(SparkSession, SparkSession.builder.appName(program).getOrCreate())

    bronze_table = full_table_name(
        args.bronze_catalog,
        arguments.schemas[arguments.schemas_bronze],
        args.bronze_table,
    )
    target_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        args.target_table,
    )
    checkpoint_loc = f"{args.checkpoints_path_prefix}/{args.target_table}"

    uuid_df = from_bronze_get_idents_df(
        spark.readStream.format("delta").table(bronze_table),
        args.id_json_path,
        args.target_table,
    )

    delta_table = DeltaTable.forName(spark, target_table)

    (
        uuid_df.writeStream.format("delta")
        .foreachBatch(
            lambda batch_df, batch_id: uuid_upsert_to_delta(delta_table, batch_df)
        )
        .option("checkpointLocation", checkpoint_loc)
        .outputMode("append")
        .trigger(availableNow=True)
        .start()
    )


if __name__ == "__main__":
    main()

==> trend_etl-2.0.0a2.tar.gz: trend_etl-2.0.0a2/trend_etl/tasks/uuid_assignment.py <==
import argparse
from typing import cast

from delta.tables import DeltaTable
from pyspark.sql import SparkSession

from trend_etl.functions.delta import full_table_name
from trend_etl.transform.idents import from_bronze_get_idents_df
from trend_etl.functions.delta import uuid_upsert_to_delta
import trend_etl.schema.args as arguments

program = "uuid_assignment"


def main() -> None:
    parser = argparse.ArgumentParser(description=f"Arguments for Trend ETL/{program}.")

    parser.add_argument(
        "--bronze-catalog",
        dest="bronze_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unity catalog to use",
    )

    parser.add_argument(
        "--target-catalog",
        dest="target_catalog",
        required=True,
        choices=arguments.catalogs,
        help="The unity catalog to use",
    )

    parser.add_argument(
        "--bronze-table",
        dest="bronze_table",
        required=True,
        choices=arguments.tables,
        help="The table in the selected schema",
    )

    parser.add_argument(
        "--target-table",
        dest="target_table",
        required=True,
        choices=arguments.tables,
        help="The table in the selected schema",
    )

    parser.add_argument(
        "--checkpoints-path-prefix",
        dest="checkpoints_path_prefix",
        required=True,
        help="The path to the folder (in S3) to store the checkpoints for this table",
    )

    parser.add_argument(
        "--id-json-path",
        dest="id_json_path",
        required=True,
        help="The the json path to the id field for the source document",
    )

    args = parser.parse_args()

    spark = cast(SparkSession, SparkSession.builder.appName(program).getOrCreate())

    bronze_table = full_table_name(
        args.bronze_catalog,
        arguments.schemas[arguments.schemas_bronze],
        args.bronze_table,
    )
    target_table = full_table_name(
        args.target_catalog,
        arguments.schemas[arguments.schemas_silver],
        args.target_table,
    )
    checkpoint_loc = f"{args.checkpoints_path_prefix}/{args.target_table}"

    uuid_df = from_bronze_get_idents_df(
        spark.readStream.format("delta").table(bronze_table),
        args.id_json_path,
        args.target_table,
    )

    delta_table = DeltaTable.forName(spark, target_table)

    (
        uuid_df.writeStream.format("delta")
        .foreachBatch(
            lambda batch_df, batch_id: uuid_upsert_to_delta(delta_table, batch_df)
        )
        .option("checkpointLocation", checkpoint_loc)
        .outputMode("append")
        .trigger(availableNow=True)
        .start()
    )


if __name__ == "__main__":
    main()
